/*
  Scrivere un programma che dato un vettore A di n interi stabilisca 
  se A contiene o meno un elemento (detto maggioritario) tale che occorra almeno 
  n/2+1 volte.
  La prima fase del programma deve prevedere la lettura da tastiera della dimensione 
  n (> 0) e degli elementi di A. Si assuma che ciascun intero inserito da tastiera sia seguito da '\n'.
  Il programma dunque scrive a video Si x\n dove x è l'elemento maggioritario o 
  No\n nel caso in cui un tale elemento non sia presente in A.

  !!!! Rispettare le specifiche per quanto riguarda input e output. 
  Ad esempio, si eviti di stampare a video frasi del tipo "Inserire n:", 
  "L'elemento maggioritario è:" ecc.
*/

#include <stdlib.h>
#include <stdio.h>

/* La funzione scandisce a e controlla se value sia maggioritario o meno. 
   Restituisce 1 in caso di esito positivo o 0 altrimenti */
 
int controlla(int a[], int n, int candidate) {

  int i, occ = 0;

  for ( i = 0; i < n; i++ ) 
	if ( a[i] == candidate) occ++;

  if( occ >= n/2+1 ) return 1;
  else return 0;

}


/* La funzione implementa la soluzione lineare di Boyer-Moore per l'identificazione del 
   maggioritario. Si mantiene in *mj il candidato corrente mentre si usa counter 
   per mantenere il contatore.  
*/

int majority( int a[], int n, int *mj ) {

  int i, counter = 1; 
  *mj = a[0];
  
  for( i = 1; i < n; i++ ) 
      if ( *mj == a[i]) counter++;
      else {
	  counter--;
	  if ( !counter ) {
	    *mj = a[i]; 
	    counter = 1;
	  }
      }

   return controlla(a, n, *mj);

}

int main() { 

  int n, *A, mj, i;

  scanf("%d", &n);
  if(n <= 0) return 1;

  A = (int *) malloc(n * sizeof(int));
  if(A == NULL) return 1;

  for( i = 0; i < n; i++ ) 
	  scanf("%d", A+i);
  
  if( majority(A, n, &mj) ) printf("Si %d\n", mj);
  else printf("No\n");

  return 0;

}